`security_groups` module
************************

Fabric tasks
------------

.. autofunction:: django_fabfile.security_groups.cleanup_security_groups
.. autofunction:: django_fabfile.security_groups.sync_rules_by_id
.. autofunction::
   django_fabfile.security_groups.replicate_security_groups

Internals
---------

.. automodule:: django_fabfile.security_groups
   :members:
